<?php

namespace Drupal\clearphpcaches\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for clearphpcaches routes.
 */
class ClearPhpCachesController extends ControllerBase {

  /**
   * Constructs a ClearPhpCachesController object.
   *
   * @param RequestStack $request_stack
   *   A request stack symfony instance.
   */
  public function __construct(
    RequestStack $request_stack,
  ) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack'),
    );
  }

  /**
   * Flushes apc and opcaches.
   */
  public function flush() {
    $this->messenger()->addMessage($this->t('APC and OPCache cleared.'));
    apcu_clear_cache();
    opcache_reset();

    return new RedirectResponse($this->reloadPage());
  }

  /**
   * Reload the previous page.
   */
  public function reloadPage() {
    $request = $this->requestStack->getCurrentRequest();
    if ($request->server->get('HTTP_REFERER')) {
      return $request->server->get('HTTP_REFERER');
    }
    else {
      return base_path();
    }
  }
}
